@@ -53,6 +53,9 @@ def _fromstring_examples():
     >>> el = fromstring('aaa<div>bbb</div>')
     >>> tostring(el)
     '<div><p>aaa</p><div>bbb</div></div>'
+    >>> el = fromstring('<body></body>')
+    >>> tostring(el)
+    '<span></span>'
     """
 
 
@@ -272,12 +275,13 @@ def youtube_video_to_thumbnail(doc):
     """
     for el in doc.xpath('//iframe[contains(@src, "www.youtube.com/embed/")]'):
         m = re.match(
-            r'https?://www\.youtube\.com/embed/([^/?]+)',
+            r'(?:https?:)?//www\.youtube\.com/embed/([^/?]+)',
             el.get("src"))
-        itagfmt = '<img src="http://img.youtube.com/vi/%s/hqdefault.jpg">'
-        itagstr = itagfmt % m.group(1)
-        itag = fromstring(itagstr)
-        replace_tag(el, itag)
+        if m:
+            itagfmt = '<img src="http://img.youtube.com/vi/%s/hqdefault.jpg">'
+            itagstr = itagfmt % m.group(1)
+            itag = fromstring(itagstr)
+            replace_tag(el, itag)
 
 
 def show_href(doc):
@@ -449,17 +453,28 @@ def add_description(doc):
     doc.body.insert(0, desc)
 
 
+def _add_style(el, style):
+    """Add inline style strings ('style') to element (Note: no doc).
+
+    >>> el = fromstring('<p>aaa</p>')
+    >>> _add_style(el, 'font-size: larger;')
+    >>> tostring(el)
+    '<p class="tsi-keep-style" style="font-size: larger;">aaa</p>'
+    """
+    el.classes |= (KEEP_STYLE,)
+    el.set('style', style)
+
+
 def add_style(doc, path, style):
     """Add inline style strings ('style') to each xpath element ('path').
 
     >>> el = fromstring('<div><p>aaa</p></div>')
-    >>> add_style(el, '//p', 'text-decoration:line-through;')
+    >>> add_style(el, '//p', 'font-size: larger;')
     >>> tostring(el)
-    '<div><p class="tsi-keep-style" style="text-decoration:line-through;">aaa</p></div>'
-    """  # noqa: E501
+    '<div><p class="tsi-keep-style" style="font-size: larger;">aaa</p></div>'
+    """
     for el in doc.xpath(path):
-        el.classes |= (KEEP_STYLE,)
-        el.set('style', style)
+        _add_style(el, style)
 
 
 def replace_tags(doc, path, tag='div'):
@@ -505,63 +520,87 @@ def convert_permalink_sign(doc, repl=''):
     >>> tostring(el)
     '<div><h1>tosixinch<a class="headerlink">…</a></h1></div>'
     """
-    for el in doc.xpath('//a[@class="headerlink"]'):
+    perms = (
+        'anchor-link',
+        'headerlink',
+    )
+    for el in doc.xpath('//a'):
         if el.text == '\u00B6':
-            el.text = repl
+            for p in perms:
+                if p in el.get('class'):
+                    el.text = repl
 
 
 def hackernews_indent(doc):
     """Narrow default indent widths, they are too wide for e-readers."""
-    for t in doc.xpath('//*[@width]'):
-        if not t.xpath('../img[@src="s.gif"]'):
-            t.attrib.pop('width')
-
     for d in doc.xpath('//td[@class="ind"]'):
         width = d.xpath('./img/@width')
         width = width[0] if width else '0'
-        dd = d.getparent()
-        comhead = dd.xpath('.//span[@class="comhead"]')[0]
-        comhead.classes.add(KEEP_STYLE)
-        comhead.set('style', 'font-weight:bold;')
-        comment = dd.xpath('.//div[@class="comment"]')[0]
-        # changing image width (px) to padding-left (px),
-        # dividing number arbitrarily.
-        block = fromstring(
-            # '<div class="%s" style="padding-left:%dpx;"></div>' % (
-            '<div class="%s" style="margin-bottom:1em;padding-left:%dpx;"></div>' % (  # noqa: E501
-                KEEP_STYLE, int(int(width) / 4)))
-        block.append(comhead)
-        block.append(comment)
-        ddd = dd.getparent()
-        ddd.replace(dd, block)
+        tr = d.getparent()
 
-    # /item? and /threads? urls are different
-    if doc.xpath('./body/table[1]'):
-        table = doc.xpath('./body/table[1]')[0]
-        wrap_tag(table, 'p')
+        # changing image width (px) to padding-left (px),
+        # reducing number arbitrarily.
+        block = make_tag('div')
+        style = 'margin-bottom:1em;padding-left:%dpx;' % int(int(width) / 4)
+        _add_style(block, style)
+
+        comhead = tr.xpath('.//span[@class="comhead"]')[0]
+        _add_style(comhead, 'font-weight:bold;')
+
+        # removing unnecessary links
+        user = comhead.xpath('./a[@class="hnuser"]')
+        if user:
+            user = user[0]
+            del user.attrib['href']
+            user.tag = 'span'
+        date = comhead.xpath('./span[@class="age"]')
+        if date:
+            date = date[0]
+            a = date.xpath('./a')
+            if a:
+                a = a[0]
+                date.text = a.text
+                date.remove(a)
+        togg = comhead.xpath('./a[@class=="togg"]')
+        if togg:
+            # simply removing 'togg' breaks tag structures,
+            # maybe shouldn't touch direct child
+            # comhead.remove(togg[0])  # NG
+            togg[0].text = ''
+        # '/threads?id=username' pattern
+        onstory = comhead.xpath('./span[@class="onstory"]')
+        if onstory:
+            onstory = onstory[0]
+            a = onstory.xpath('./a')
+            if a:
+                a = a[0]
+                onstory.text += a.text
+                onstory.remove(a)
+
+        block.append(comhead)
+
+        comment = tr.xpath('.//div[@class="comment"]')
+        if comment:  # sometimes comment is folded
+            for c in comment:
+                block.append(c)
+
+        body = tr.getparent()
+        body.replace(tr, block)
 
     # Add sitename hint to h1
-    h1 = doc.xpath('./body/h1')[0]
-    h1.text = 'hn - ' + h1.text.split(' | ')[0]
+    replace_h1(doc, r'^(.+?) \| .*', r'hn - \1')
 
 
 def reddit_indent(doc):
-    """Render reddit.com's comment indent styles.
-
-    They are in the site's external css.
-    So we have to insert inline css made from it.
-    """
+    """Narrow default indent widths, they are too wide for e-readers."""
     for el in doc.xpath('//div[@class=="comment"]'):
-        el.set('style', 'margin-left:8px;')
-        el.classes.add(KEEP_STYLE)
+        _add_style(el, 'margin-left:8px;')
         path = './/p[@class="tagline"]/a[@class=="author"]'
         for e in el.xpath(path):
-            e.set('style', 'font-weight:bold;')
-            e.classes.add(KEEP_STYLE)
+            _add_style(e, 'font-weight:bold;')
 
-    # Add sitename to h1
-    h1 = doc.xpath('./body/h1')[0]
-    h1.text = 'reddit - ' + h1.text
+    # Add sitename hint to h1
+    replace_h1(doc, r'^(.+)$', r'reddit - \1')
 
 
 def github_self_anchor(doc):
