@@ -117,8 +117,6 @@ class StyleSheet(object):
         conv_dict = {
             'prince': using('prince'),
             'weasyprint': using('weasyprint'),
-            'wkhtmltopdf': using('wkhtmltopdf'),
-            'prince_or_weasyprint': using('prince') or using('weasyprint'),
         }
         context.update(conv_dict)
 
